Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(291)

Unified Diff: src/objects.h

Issue 23014007: Rename "parallel recompilation" to "concurrent recompilation". (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/mips/builtins-mips.cc ('k') | src/objects.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/objects.h
diff --git a/src/objects.h b/src/objects.h
index 96b4011664bef5255601b653a0a664e1a7367551..b95862258e203cb40ef68dec60023f5d59b2600a 100644
--- a/src/objects.h
+++ b/src/objects.h
@@ -6966,7 +6966,7 @@ class JSFunction: public JSObject {
// Mark this function for lazy recompilation. The function will be
// recompiled the next time it is executed.
void MarkForLazyRecompilation();
- void MarkForParallelRecompilation();
+ void MarkForConcurrentRecompilation();
void MarkForInstallingRecompiledCode();
void MarkInRecompileQueue();
@@ -6983,11 +6983,10 @@ class JSFunction: public JSObject {
// Tells whether or not the function is already marked for lazy
// recompilation.
inline bool IsMarkedForLazyRecompilation();
- inline bool IsMarkedForParallelRecompilation();
+ inline bool IsMarkedForConcurrentRecompilation();
inline bool IsMarkedForInstallingRecompiledCode();
// Tells whether or not the function is on the parallel
// recompilation queue.
inline bool IsInRecompileQueue();
// Check whether or not this function is inlineable.
« no previous file with comments | « src/mips/builtins-mips.cc ('k') | src/objects.cc » ('j') | no next file with comments »
@@ -6983,11 +6983,10 @@ class JSFunction: public JSObject {
inline bool IsMarkedForInstallingRecompiledCode();
- // Tells whether or not the function is on the parallel
- // recompilation queue.
+ // Tells whether or not the function is on the concurrent recompilation queue.
inline bool IsInRecompileQueue();
// Check whether or not this function is inlineable.

Powered by Google App Engine
This is Rietveld 408576698